/****************************************************************************
**
** Copyleft (C) 2015 Dominique Laporte <laporte.educnat@gmail.com>
**
** This file is part of ecoserre
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file. Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
****************************************************************************/

#include <SoftwareSerial.h>

const bool debug = false;   // pour déboggage

const int RX = 2;    // pin Shield Arduino pour reception
const int TX = 3;    // pin Shield Arduino pour transmission

const int baudRate = 9600;

const char *PANID = "1111";      // adresse reseau
const char *MYID  = "1002";      // adresse du XBee
const char *DLID  = "1001";      // adresse de destination
const char *CHID  = "10";        // n° de canal (0x10 à 0x20)
const char *BAUD  = "3";         // vitesse transmission (3: 9600, 4:19200, 5:38400, 6:57600, 7:115200)

SoftwareSerial xbeeSerial(TX, RX);     // pin 2 = RX Arduino, pin3 = TX Arduino 

//==== Configuration d'un Xbee par commandes AT ====//
void setup()
{
  Serial.begin(baudRate);            // liaison série de la console (débugage)
  xbeeSerial.begin(baudRate);        // Liaison série du module XBEE
  
  while ( xbeeSerial.read() != -1);  // vide le buffer

  if ( debug )
    Serial.println("init");
  setXBEE("+++");

  // attente réponse OK de la commande AT
  char thisByte = 0;
  while (thisByte != '\r')
    if (xbeeSerial.available() > 0) {
      thisByte = xbeeSerial.read();
      if ( debug )
        Serial.print(thisByte);
      }
  Serial.println("");

  char  buffer[11] = "";
  setXBEE("ATRE\r");        // configuration usine par defaut
  setXBEE(strcat(strcat(strcpy(buffer,"ATID"), PANID), "\r"));   // adresse du reseau PAN
  setXBEE(strcat(strcat(strcpy(buffer,"ATMY"), MYID), "\r"));    // set my address using 16-bit addressing
  setXBEE(strcat(strcat(strcpy(buffer,"ATDL"), DLID), "\r"));    // adresse de destination sur 16 bits  
  setXBEE(strcat(strcat(strcpy(buffer,"ATCH"), CHID), "\r"));    // canal
  setXBEE(strcat(strcat(strcpy(buffer,"ATBD"), BAUD), "\r"));    // vitesse de transmission
  setXBEE("ATDH0\r");       // pas de partie haute, adresse 16 bits
  setXBEE("ATCE0\r");       // end device
  setXBEE("ATWR\r");        // enregistrement
  setXBEE("ATCN\r");        // put the radio in data mode
  
  // attente réponse commandes AT
  while ( xbeeSerial.available() < 0 );
  
  char c = xbeeSerial.read();
  while ( c != -1 ) {
    if ( c != 0xD )
      Serial.print(c);
    else
      Serial.print(" ");
    c = xbeeSerial.read();
    }
}

void loop()
{
  // lecture donnees XBee distant
  char c = xbeeSerial.read();

  // donnees transferees sur port serie
  if ( c != -1 )
    Serial.print(c);
}

void setXBEE(char *buffer)
{
  if ( debug ) {
    Serial.println(buffer);
    Serial.print("sent: "); Serial.println(xbeeSerial.print(buffer));
    }
  
  delay(100);
}

